# libgastosluxu

Módulo para exemplificar construção de projetos Python no curso PyTools

[![Build Status](https://travis-ci.com/luxu/libgastosluxu.svg?branch=main)](https://travis-ci.com/luxu/libgastosluxu)
[![Updates](https://pyup.io/repos/github/luxu/libgastosluxu/shield.svg)](https://pyup.io/repos/github/luxu/libgastosluxu/)
[![Python 3](https://pyup.io/repos/github/luxu/libgastosluxu/python-3-shield.svg)](https://pyup.io/repos/github/luxu/libgastosluxu/)

Para instalar:
```console
python -m venv .venv
.\.venv\Scripts\activate
pip install -r requeriments
```

Para conferir qualidade ao código:
```console
flake8
```